pub struct DnsServer { /* private fields */ }Expand description
Minimal UDP DNS server that answers A queries with fake IPs from a DnsMap.
Runs in a dedicated blocking thread (DNS is inherently synchronous and low-throughput enough that this is optimal).
Implementations
Sourceimpl DnsServer
impl DnsServer
Sourcepub fn bind(addr: SocketAddr, map: DnsMap) -> Result<Self>
pub fn bind(addr: SocketAddr, map: DnsMap) -> Result<Self>
Bind to addr and create a server backed by map.
Sourcepub fn local_addr(&self) -> SocketAddr
pub fn local_addr(&self) -> SocketAddr
Return the local address the server is listening on.